summaryrefslogtreecommitdiff
path: root/window.h
diff options
context:
space:
mode:
authorDarkvater <darkvater@openttd.org>2006-12-29 17:16:12 +0000
committerDarkvater <darkvater@openttd.org>2006-12-29 17:16:12 +0000
commit17f42ef491e8e46ec383d20d3a4c145eb41e5171 (patch)
tree6b85f6db41b539878c171e1f6c86ea6e5b4632ff /window.h
parent49eb2a91ab7f23cd27c90c507c11c99d9941e803 (diff)
downloadopenttd-17f42ef491e8e46ec383d20d3a4c145eb41e5171.tar.xz
(svn r7619) -Feature (Internal): Add support for modal children. It's a window-child that
will block activity for the parent window until the modal popup is dismissed.
Diffstat (limited to 'window.h')
-rw-r--r--window.h17
1 files changed, 9 insertions, 8 deletions
diff --git a/window.h b/window.h
index 80304e189..39a648abe 100644
--- a/window.h
+++ b/window.h
@@ -264,13 +264,14 @@ typedef struct WindowDesc {
} WindowDesc;
enum WindowDefaultFlag {
- WDF_STD_TOOLTIPS = 1, /* use standard routine when displaying tooltips */
- WDF_DEF_WIDGET = 2, /* default widget control for some widgets in the on click event */
- WDF_STD_BTN = 4, /* default handling for close and drag widgets (widget no 0 and 1) */
-
- WDF_UNCLICK_BUTTONS = 16, /* Unclick buttons when the window event times out */
- WDF_STICKY_BUTTON = 32, /* Set window to sticky mode; they are not closed unless closed with 'X' (widget 2) */
- WDF_RESIZABLE = 64, /* A window can be resized */
+ WDF_STD_TOOLTIPS = 1, /* use standard routine when displaying tooltips */
+ WDF_DEF_WIDGET = 2, /* default widget control for some widgets in the on click event */
+ WDF_STD_BTN = 4, /* default handling for close and drag widgets (widget no 0 and 1) */
+
+ WDF_UNCLICK_BUTTONS = 16, /* Unclick buttons when the window event times out */
+ WDF_STICKY_BUTTON = 32, /* Set window to sticky mode; they are not closed unless closed with 'X' (widget 2) */
+ WDF_RESIZABLE = 64, /* A window can be resized */
+ WDF_MODAL = 128, /* The window is a modal child of some other window, meaning the parent is 'inactive' */
};
/* can be used as x or y coordinates to cause a specific placement */
@@ -598,7 +599,7 @@ enum WindowFlags {
WF_DISABLE_VP_SCROLL = 1 << 10,
WF_WHITE_BORDER_ONE = 1 << 11,
- WF_WHITE_BORDER_MASK = 3 << 11,
+ WF_WHITE_BORDER_MASK = 1 << 12 | WF_WHITE_BORDER_ONE,
WF_SCROLL2 = 1 << 13,
};